@@ -17,10 +17,13 @@ require AutoLoader;
 
 );
 
-$VERSION = '2.5.3';
+$VERSION = '2.5.7';
 
 bootstrap HTML::CTPP2 $VERSION;
 
+# Thread-safe
+sub CLONE_SKIP { return 1; }
+
 # Autoload methods go after =cut, and are processed by the autosplit program.
 1;
 __END__;
@@ -66,7 +69,7 @@ __END__;
   my $Result = $T -> output($Bytecode);
   or
   my $SourceCharset = 'iso-8859-5';
-  my $SestinationCharset = 'utf-8';
+  my $DestinationCharset = 'utf-8';
   my $Result = $T -> output($Bytecode, $SourceCharset, $DestinationCharset);
 
   Now check output:
@@ -306,6 +309,7 @@ __END__;
     * MB_TRUNCATE
     * MIN
     * NUM_FORMAT
+    * NUMERAL
     * OBJ_DUMP
     * RANDOM
     * SIZE
@@ -331,7 +335,7 @@ __END__;
   You can also change some internal variables of CTPP engine:
   my $T = new HTML::CTPP2(arg_stack_size      => 1024,
                           code_stack_size     => 1024,
-                          steps_limit         => 10240,
+                          steps_limit         => 1024*1024,
                           max_functions       => 1024,
                           source_charset      => 'CP1251',
                           destination_charset => 'utf-8');
@@ -381,7 +385,7 @@ __END__;
   or
 
   my $SourceCharset = 'iso-8859-5';
-  my $SestinationCharset = 'utf-8';
+  my $DestinationCharset = 'utf-8';
   my $Result = $T -> output($Bytecode, $SourceCharset, $DestinationCharset);
 
 
